#
# Eventhub
#

resource "azurerm_resource_group" "this" {
  name     = var.resource_group_name
  location = var.location
}

resource "azurerm_eventhub_namespace" "this" {
  name                = var.eventhub.namespace.name
  resource_group_name = var.resource_group_name
  location            = var.location
  sku                 = var.eventhub.namespace.sku
  depends_on          = [azurerm_resource_group.this]
}

resource "azurerm_eventhub" "this" {
  name                = var.eventhub.name
  namespace_id        = azurerm_eventhub_namespace.this.id
  message_retention   = var.eventhub.retention_days
  partition_count     = var.eventhub.partition_count
  depends_on          = [azurerm_resource_group.this]
}

resource "azurerm_eventhub_authorization_rule" "this" {
  name                = "${var.name}-${var.forwarder.name}"
  namespace_name      = var.eventhub.namespace.name
  eventhub_name       = var.eventhub.name
  resource_group_name = var.resource_group_name
  listen              = true
  send                = false
  manage              = false
  depends_on          = [azurerm_resource_group.this, azurerm_eventhub_namespace.this, azurerm_eventhub.this]
}


#
# Function App
#
resource "azurerm_storage_account" "this" {
  name                     = var.forwarder.storage_account.name
  resource_group_name      = var.resource_group_name
  account_replication_type = var.forwarder.storage_account.replication_type
  account_tier             = var.forwarder.storage_account.tier
  location                 = var.location
  depends_on               = [azurerm_resource_group.this]
}

resource "azurerm_service_plan" "this" {
  name                = var.name
  resource_group_name = var.resource_group_name
  location            = azurerm_resource_group.this.location
  os_type             = "Linux"
  sku_name            = var.forwarder.service_plan_type
}

resource "azurerm_log_analytics_workspace" "this" {
  name                = var.name
  location            = azurerm_resource_group.this.location
  resource_group_name = var.resource_group_name
  sku                 = "PerGB2018"
  retention_in_days   = 90
}

resource "azurerm_application_insights" "this" {
  name                = var.name
  resource_group_name = var.resource_group_name
  location            = azurerm_resource_group.this.location
  workspace_id        = azurerm_log_analytics_workspace.this.id
  application_type    = "web"
}

resource "azurerm_linux_function_app" "eventhub-forwarder" {
#  count = 0
  name                        = var.name
  resource_group_name         = var.resource_group_name
  location                    = azurerm_resource_group.this.location
  storage_account_name        = var.forwarder.storage_account.name
  storage_account_access_key  = azurerm_storage_account.this.primary_access_key
  service_plan_id             = azurerm_service_plan.this.id
  functions_extension_version = "~4"
  site_config {
    application_insights_key               = azurerm_application_insights.this.instrumentation_key
    application_insights_connection_string = azurerm_application_insights.this.connection_string
    application_stack {
      python_version = "3.11"
    }
  }
  app_settings = {
    BRONTO_API_KEY            = var.bronto_config.ingestion_key
    BRONTO_INGESTION_ENDPOINT = var.bronto_config.ingestion_endpoint
    FORWARDER_NAME            = var.name
    EVENTHUB_CONNECT_STRING   = azurerm_eventhub_authorization_rule.this.primary_connection_string
    EVENTHUB_NAME             = var.eventhub.name
    WEBSITE_RUN_FROM_PACKAGE  = var.forwarder.pkg_url
    BRONTO_COLLECTION         = var.bronto_config.default_collection
  }
}
